/*
	$Id: inputsource_provider_file.h,v 1.11 2002/07/16 12:39:46 mbn Exp $

	------------------------------------------------------------------------
	ClanLib, the platform independent game SDK.

	This library is distributed under the GNU LIBRARY GENERAL PUBLIC LICENSE
	version 2. See COPYING for details.

	For a total list of contributers see CREDITS.

	See http://www.clanlib.org
	------------------------------------------------------------------------
*/

//! clanCore="I/O Data"
//! header=core.h

#ifndef header_inputsource_provider_file
#define header_inputsource_provider_file

#include "inputsource_provider.h"
#include <string>

class CL_InputSource;

//: The Input Source Provider File Class    
//- <p>CL_InputSourceProvider_File is a subclass of CL_InputSourceProvider.
//- It provides a way to treat normal files as input sources and to read and write them 
//- in a endian transparent manner.</p>

class CL_InputSourceProvider_File : public CL_InputSourceProvider
{
//! Construction:
public:
	//: Construtcs a file input source provider.
	//param path: File to create a source for.
	CL_InputSourceProvider_File(const std::string &path);

	//: Open input source using file as its source.
	//param filename: Filename to open.
	//return: InputSource for the file.
	virtual CL_InputSource *open_source(const std::string &filename);

	//: Get full path to source.
	std::string get_path(const std::string &filename);

	//: Clone the provider.
	//- <p>Creates a new instance of the class with the same internal data.
	//- This is equivaled to <i>new CL_InputSourceProvider_File(get_path())</i>.</p>
	//return: New instance of the current provider.
	virtual CL_InputSourceProvider *clone();

//! Implementation:
private:
	std::string provider_path;
};

#endif
