/*
	$Id: size.h,v 1.17 2002/10/20 14:59:24 mbn Exp $

	------------------------------------------------------------------------
	ClanLib, the platform independent game SDK.

	This library is distributed under the GNU LIBRARY GENERAL PUBLIC LICENSE
	version 2. See COPYING for details.

	For a total list of contributers see CREDITS.

	See http://www.clanlib.org
	------------------------------------------------------------------------
*/

//! clanCore="Math"
//! header=core.h

#ifndef header_size
#define header_size

//: 2D (width,height) size structure.
class CL_Size
{
//! Construction:
public:
	//: Constructs a size structure.
	//param width: Initial width of size structure.
	//param height: Initial height of size structure.
	//param size: Size structure to construct this one from.
	CL_Size() { return; }

	CL_Size(int width, int height)
	: width(width), height(height) { }

	CL_Size(const CL_Size &s)
	{ width = s.width; height = s.height; }

//! Attributes:
public:
	//: Size width.
	int width;

	//: Size height.
	int height;

//! Operations:
public:
	//: Size += Size operator.
	CL_Size &operator+=(const CL_Size &s)
	{ width += s.width; height += s.height; return *this; }

	//: Size -= Size operator.
	CL_Size &operator-=(const CL_Size &s)
	{ width -= s.width; height -= s.height; return *this; }
	
	//: Size + Size operator.
	CL_Size operator+(const CL_Size &s) const
	{ return CL_Size(width + s.width, height + s.height); }

	//: Size - Size operator.
	CL_Size operator-(const CL_Size &s) const
	{ return CL_Size(width - s.width, height - s.height); }

};

//: 2D (width,height) floating point size structure.
class CL_Sizef
{
//! Construction:
public:
	//: Constructs a size structure.
	//param width: Initial width of size structure.
	//param height: Initial height of size structure.
	//param size: Size structure to construct this one from.
	CL_Sizef() { return; }

	CL_Sizef(float width, float height)
	: width(width), height(height) { }

	CL_Sizef(const CL_Sizef &s)
	{ width = s.width; height = s.height; }

//! Attributes:
public:
	//: Size width.
	float width;

	//: Size height.
	float height;

//! Operations:
public:
	//: Size += Size operator.
	CL_Sizef &operator+=(const CL_Sizef &s)
	{ width += s.width; height += s.height; return *this; }

	//: Size -= Size operator.
	CL_Sizef &operator-=(const CL_Sizef &s)
	{ width -= s.width; height -= s.height; return *this; }
	
	//: Size + Size operator.
	CL_Sizef operator+(const CL_Sizef &s) const
	{ return CL_Sizef(width + s.width, height + s.height); }

	//: Size - Size operator.
	CL_Sizef operator-(const CL_Sizef &s) const
	{ return CL_Sizef(width - s.width, height - s.height); }

};

#endif
