/*
	$Id: event_listener.h,v 1.19 2002/07/16 12:39:46 mbn Exp $

	------------------------------------------------------------------------
	ClanLib, the platform independent game SDK.

	This library is distributed under the GNU LIBRARY GENERAL PUBLIC LICENSE
	version 2. See COPYING for details.

	For a total list of contributers see CREDITS.

	See http://www.clanlib.org
	------------------------------------------------------------------------
*/

//! clanCore="System"
//! header=core.h

#ifndef header_event_listener
#define header_event_listener

class CL_EventTrigger;
class CL_EventListener_Generic;

//: Event listening interace.
//- <p>The event listener is used to collect a set of events, identified as CL_EventTrigger,
//- and wait for one of them to occur. This is analog to the low level C socket select()
//- function, except that this one operates on clanlib objects.</p>
class CL_EventListener
{
//! Construction:
public:
	//: Constructs an event listener object.
	//param trigger: Initial trigger to be added to listener.
	CL_EventListener();

	CL_EventListener(CL_EventTrigger *trigger);

	//: Event Listener destructor.
	virtual ~CL_EventListener();

//! Attributes:
public:

//! Operations:
public:
	//: Adds an event trigger to the listener.
	void add_trigger(CL_EventTrigger *trigger);

	//: Removes an event trigger from the listener.
	void remove_trigger(CL_EventTrigger *trigger);

	//: Removes all event triggers from the listener.
	void clear();

	//: Resets all event triggers added to the listener.
	void reset_all();

	//: Wait until one of the events triggers.
	//param timeout - The timeout is in milliseconds. If -1, waits infinitely.
	//- <p>If timeout = -1, this function will not timeout.</p>
	//returns: True if an event triggered, false if it timed out.
	bool wait(int timeout = -1);

//! Implementation:
private:
	CL_EventListener_Generic *impl;
};

#endif
