/*
	$Id: canvas.h,v 1.17 2002/07/25 12:38:47 mbn Exp $

	------------------------------------------------------------------------
	ClanLib, the platform independent game SDK.

	This library is distributed under the GNU LIBRARY GENERAL PUBLIC LICENSE
	version 2. See COPYING for details.

	For a total list of contributers see CREDITS.

	See http://www.clanlib.org
	------------------------------------------------------------------------
*/

//! clanDisplay="Display 2D"
//! header=display.h

#ifndef header_canvas
#define header_canvas

class CL_Size;
class CL_PixelBuffer;
class CL_GraphicContext;
class CL_PixelBuffer;
class CL_Canvas_Generic;

//: Canvas pixelbuffer/surface class.

//- <p>The Canvas class is a special pixelbuffer that is optimized for rapid
//- changes in its pixel data. This is opposite to CL_Surface, which is optimzied
//- for no changes in its pixel data.</p>
class CL_Canvas
{
//! Construction:
public:
	//: Pixel formats a canvas supports.
	enum Format
	{
		rgba32_8888,
		rgb32_888,
		rgb16_565
	};

	//: Constructs a canvas.
	//param size: Dimensions of canvas, in pixels.
	//param format: Pixel format of canvas.
	//param use_colorkey: If true, <i>colorkey</i> specifies a single color that marks transparency.
	//param colorkey: If enabled, colorkey specifies a color that is transparent.
	//param provider: Pixel buffer containing initial pixel data to be filled into canvas.
	//param delete_provider: If true, canvas will delete provider after copying its contents.

	CL_Canvas(
		const CL_Size &size,
		Format format = rgba32_8888,
		bool use_colorkey = false, unsigned int colorkey = 0x12345678);

	CL_Canvas(
		CL_PixelBuffer *provider, bool delete_provider = false,
		Format format = rgba32_8888,
		bool use_colorkey = false, unsigned int colorkey = 0x12345678);

	CL_Canvas(const CL_Canvas &copy);

	CL_Canvas();

	virtual ~CL_Canvas();

//! Attributes:
public:
	//: Returns the pixel buffer of the canvas.
	CL_PixelBuffer &get_pixelbuffer();

	const CL_PixelBuffer &get_pixelbuffer() const;

	//: Returns the graphic context of the canvas.
	CL_GraphicContext *get_gc();

//! Operations:
public:
	//: Copy assignment operator.
	CL_Canvas &operator =(const CL_Canvas &copy);

	//: Draw canvas onto graphic context.
	void draw(int x, int y, CL_GraphicContext *gc = 0);

//! Implementation:
private:
	CL_Canvas_Generic *impl;
};

#endif
