	/*
	$Id: input_buffer.h,v 1.10 2002/08/06 11:44:30 sphair Exp $

	------------------------------------------------------------------------
	ClanLib, the platform independent game SDK.

	This library is distributed under the GNU LIBRARY GENERAL PUBLIC LICENSE
	version 2. See COPYING for details.

	For a total list of contributers see CREDITS.

	See http://www.clanlib.org
	------------------------------------------------------------------------
*/

//! clanDisplay="Input"
//! header=display.h

#ifndef header_inputbuffer
#define header_inputbuffer

#ifdef WIN32
#pragma warning( disable : 4786)
#endif

#include <queue>
#include "input_event.h"
#include "../signals.h"

class CL_Component;
class CL_InputDevice;
class CL_InputContext;
class CL_InputBuffer_Generic;

//: Input buffer interface.
//- <p> Use this class to read buffered keys from the keyboard or any other device. </p>
class CL_InputBuffer
{
//! Construction:
public:
	//: Constructs an input buffer.
	//param ic: Input context that input buffer should connect to get keys.
	//param sig_key_down: Signal input buffer should connect to get key presses.
	//param sig_key_up: Signal input buffer should connect to get key released.
	//param device: Input device that input buffer should connect to get keys.
	//- <p>Detailed description that explains what this damn constructors really do.</p>
	CL_InputBuffer();

	CL_InputBuffer(CL_InputDevice &device);

	CL_InputBuffer(CL_InputContext *ic);

	CL_InputBuffer(const CL_InputBuffer &copy);

	//: Input Buffer destructor.
	virtual ~CL_InputBuffer();

//! Attributes:
public:
	//: Returns number of keys still available in the buffer.
	//return: Number of key values left in buffer.
	int keys_left() const;

	//: Returns the next key in the buffer, but unlike pop_key() it does not
	//: pop it from the input buffer.
	CL_InputEvent peek_key() const;

//! Operations:
public:
	//: Copy assignment operator.
	CL_InputBuffer &operator =(const CL_InputBuffer &copy);

	//: Adds a device that input buffer should connect to get keys.
	void add_device(CL_InputDevice &device);

	//: Adds all devices from a inputcontext that input buffer should connect to get keys.
	void add_devices(CL_InputContext *ic);
	
	//: Pops the next key in the buffer and returns it.
	CL_InputEvent pop_key();

	//: Clears the buffer.
	void clear();
	
//! Implementation:
private:
	CL_InputBuffer_Generic *impl;
};

#endif
