	/*
	$Id: input_button.h,v 1.9 2002/08/06 12:06:40 sphair Exp $

	------------------------------------------------------------------------
	ClanLib, the platform independent game SDK.

	This library is distributed under the GNU LIBRARY GENERAL PUBLIC LICENSE
	version 2. See COPYING for details.

	For a total list of contributers see CREDITS.

	See http://www.clanlib.org
	------------------------------------------------------------------------
*/

//! clanDisplay="Input"
//! header=display.h

#ifndef header_inputbutton
#define header_inputbutton

#include "input_event.h"
#include "key_binding.h"

class CL_InputButton_Generic;

//: Input Button interface.
//- Use this class to bind inputevents to this class. You can then check if any input events has
//- be activated (like a mouse-press, a certain keypress etc).
//- Useful for things like mapping SPACE and LEFT MOUSE to a Fire Action.
class CL_InputButton
{
//! Construction:
public:
	//: Constructor.
	CL_InputButton();

	//: Copy constructor.
	CL_InputButton(const CL_InputButton &copy);

	//: Destructor.
	virtual ~CL_InputButton();

//! Attributes:
public:
	//: Returns the number of presses this inputbutton has been pressed.
	//- Returns - Number of key presses of this inputbutton.
	int peek_pressed() const;

	//: Returns the CL_InputEvent of the last input press.
	//- Returns - CL_InputEvent of the last input press.
	CL_InputEvent peek_key() const;

//! Operations:
public:
	//: Copy assignment operator.
	CL_InputButton &operator =(const CL_InputButton &copy);

	//: Binds a key.
	void bind(const CL_KeyBinding &key);

	//: Unbinds a key.
	void unbind(const CL_KeyBinding &key);

	//: Unbinds all keys.
	void unbind_all();

	//: Returns a list over all keys bound to this inputbutton.
	const std::list<CL_KeyBinding> &get_bindings() const;

	//: Returns the number of presses this inputbutton has been pressed.
	//: This clears the state of this inputbutton.
	//- Returns - Number of key presses of this inputbutton.
	int pop_pressed();

	//: Returns the CL_InputEvent of the last input press.
	//: This clears the state of the inputbutton.
	//- Returns - CL_InputEvent containing information on last input press.
	CL_InputEvent pop_key();

	//: Clears the state of the inputbutton.
	void clear();

//! Implementation:
private:
	CL_InputButton_Generic *impl;
};

#endif
