/*
	$Id: input_context.h,v 1.14 2002/08/19 11:07:15 sphair Exp $

	------------------------------------------------------------------------
	ClanLib, the platform independent game SDK.

	This library is distributed under the GNU LIBRARY GENERAL PUBLIC LICENSE
	version 2. See COPYING for details.

	For a total list of contributers see CREDITS.

	See http://www.clanlib.org
	------------------------------------------------------------------------
*/

//! clanDisplay="Input"
//! header=display.h

#ifndef header_input_context
#define header_input_context

#include "../signals.h"

class CL_InputDevice;
class CL_InputEvent;
class CL_InputContext_Generic;

//: Input events interface.
//- <p>An input context is a collection of inputdevices available in
//- a displaywindow.</p>
class CL_InputContext
{
//! Construction:
public:
	//: Constructs an input context.
	//param num_keyboards: Number of keyboards to be associated with this input context.
	//param num_mice: Number of mice to be associated with this input context.
	//param num_joysticks: Number of joysticks to be associated with the input context.
	CL_InputContext(
		int num_keyboards,
		int num_mice,
		int num_joysticks);

	~CL_InputContext();

//! Attributes:
public:
	//: Returns the number of keyboards available.
	int get_keyboard_count() const;

	//: Returns the number of mice available.
	int get_mouse_count() const;

	//: Returns the number of joysticks available.
	int get_joystick_count() const;

	//: Returns the input device for the specified keyboard.
	CL_InputDevice &get_keyboard(int keyboard = 0);

	//: Returns the input device for the specified mouse.
	CL_InputDevice &get_mouse(int mouse = 0);

	//: Returns the input device for the specified joystick.
	CL_InputDevice &get_joystick(int joystick = 0);

//! Operations:
public:

//! Implementation:
private:
	CL_InputContext_Generic *impl;
};

#endif
