/*
	$Id: input_device.h,v 1.14 2002/08/05 21:11:12 sphair Exp $

	------------------------------------------------------------------------
	ClanLib, the platform independent game SDK.

	This library is distributed under the GNU LIBRARY GENERAL PUBLIC LICENSE
	version 2. See COPYING for details.

	For a total list of contributers see CREDITS.

	See http://www.clanlib.org
	------------------------------------------------------------------------
*/

//! clanDisplay="Input"
//! header=display.h

#ifndef header_inputdevice
#define header_inputdevice

#ifdef WIN32
#pragma warning( disable : 4786)
#endif

#include <string>

#include "../signals.h"

class CL_InputDevice_Generic;
class CL_InputEvent;

//: General input device.
class CL_InputDevice
{
public:
	//: Input device types.
	enum Type
	{
		keyboard,
		mouse,
		joystick
	};

//! Construction:
public:
	//: Constructs an input device.
	CL_InputDevice();

	CL_InputDevice(const CL_InputDevice &copy);

	~CL_InputDevice();

//! Attributes:
public:
	//: Returns the input device type.
	Type get_type() const;

	//: Key name for specified identifier (A, B, Space, Backspace, Mouse Left).
	std::string get_key_name(int id) const;

	//: Returns true if the passed key code is down for this device.
	//- <p>See keys.h for list of key codes.</p>
	bool get_keycode(int keycode) const;
	
	//: Returns the x position of the device.
	//- <p>Only valid for mouse and joystick.</p>
	int get_x() const;

	//: Returns the y position of the device.
	//- <p>Only valid for mouse and joystick.</p>
	int get_y() const;

//! Operations:
public:
	CL_InputDevice &operator =(const CL_InputDevice &copy);

	//: Sets the position of the device.
	//- <p>Only valid for mouse.</p>
	void set_position(int x, int y);

//! Signals:
public:
	//: Signal emitted when key is pressed.
	CL_Signal_v1<const CL_InputEvent &> &sig_key_down();

	//: Signal emitted when key is released.
	CL_Signal_v1<const CL_InputEvent &> &sig_key_up();

	//: Signal emitted when key is double clicked.
	CL_Signal_v1<const CL_InputEvent &> &sig_key_dblclk();

	//: Signal emitted when specified device is moved.
	CL_Signal_v1<const CL_InputEvent &> &sig_move();

//! Implementation:
public:
	CL_InputDevice(CL_InputDevice_Generic *impl);

private:
	CL_InputDevice_Generic *impl;
};

#endif
