/*
	$Id: input_event.h,v 1.1 2002/08/01 10:39:23 sphair Exp $

	------------------------------------------------------------------------
	ClanLib, the platform independent game SDK.

	This library is distributed under the GNU LIBRARY GENERAL PUBLIC LICENSE
	version 2. See COPYING for details.

	For a total list of contributers see CREDITS.

	See http://www.clanlib.org
	------------------------------------------------------------------------
*/

//! clanDisplay="Input"
//! header=display.h

#ifndef header_inputevent
#define header_inputevent

#include "input_device.h"
#include "../Core/Math/point.h"

//: Structure descripting an input device event.
class CL_InputEvent
{
public:
	//: Event types.
	enum Type
	{
		no_key,
		pressed,
		released,
		double_clicked,
		moved
	};

//! Construction:
public:
	//: Constructs a 'NoKey' key.
	CL_InputEvent();

	~CL_InputEvent();

//! Attributes:
public:
	//: Key identifier.
	int id;

	//: Character sequence generated by event.
	std::string str;

	//: Event type.
	Type type;

	//: Device that event originates from.
	CL_InputDevice device;
	
	//: Mouse position at event time.
	CL_Point mouse_pos;

	//: Set to true if left alt was down when event occoured.
	bool left_alt;

	//: Set to true if right alt was down when event occoured.
	bool right_alt;

	//: Set to true if left control was down when event occoured.
	bool left_ctrl;

	//: Set to true if right control was down when event occoured.
	bool right_ctrl;

	//: Set to true if left shift was down when event occoured.
	bool left_shift;

	//: Set to true if right shift was down when event occoured.
	bool right_shift;

	//: Specifies the repeat count for this event.
	//- <p>The variable contains the number of times the keystroke is
	//: autorepeated as a result of the user holding down the key.</p>
	int repeat_count;
};

#endif
