/*
	$Id: mouse.h,v 1.2 2002/08/09 13:06:43 sphair Exp $

	------------------------------------------------------------------------
	ClanLib, the platform independent game SDK.

	This library is distributed under the GNU LIBRARY GENERAL PUBLIC LICENSE
	version 2. See COPYING for details.

	For a total list of contributers see CREDITS.

	See http://www.clanlib.org
	------------------------------------------------------------------------
*/

//! clanDisplay="Input"
//! header=display.h

#ifndef header_mouse
#define header_mouse

#ifdef WIN32
#pragma warning( disable : 4786)
#endif

#include <string>
#include "../signals.h"

class CL_InputEvent;
class CL_InputDevice;
class CL_Sprite;

//: Class for handling mouse device.
class CL_Mouse
{
//! Construction:
public:

//! Attributes:
public:
	//: Returns the number of mice available.
	static int get_device_count();

	//: Returns a mouse device.
	static CL_InputDevice &get_device(int mouse = 0);

	//: Returns the x position of a mouse device.
	static int get_x(int mouse = 0);
	
	//: Returns the y position of a mouse device.
	static int get_y(int mouse = 0);
	
	//: Returns true if the key with the specified key code is pressed.
	static bool get_keycode(int keycode, int mouse = 0);

	//: Key name for specified identifier (Mouse Left, Mouse Right).
	static std::string get_key_name(int id);

//! Operations:
public:
	//: Sets the position of a mouse device.
	static void set_position(int x, int y, int mouse = 0);

	//: Set a custom mouse cursor.
	static void set_cursor(const CL_Sprite &sprite);

	//: Shows the mouse cursor. 
	static void show();

	//: Hides the mouse cursor.
	static void hide();

//! Signals:
public:
	//: Signal emitted when mouse is pressed on the specified mouse.
	static CL_Signal_v1<const CL_InputEvent &> &sig_key_down(int mouse = 0);

	//: Signal emitted when mouse is released on the specified mouse.
	static CL_Signal_v1<const CL_InputEvent &> &sig_key_up(int mouse = 0);

	//: Signal emitted when mouse is double clicked.
	static CL_Signal_v1<const CL_InputEvent &> &sig_key_dblclk(int mouse = 0);

	//: Signal emitted when specified mouse is moved.
	static CL_Signal_v1<const CL_InputEvent &> &sig_move(int mouse = 0);

//! Implementation:
private:
};

#endif
