/*
	$Id: sprite_packer.h,v 1.13 2002/07/17 11:44:21 mbn Exp $

	------------------------------------------------------------------------
	ClanLib, the platform independent game SDK.

	This library is distributed under the GNU LIBRARY GENERAL PUBLIC LICENSE
	version 2. See COPYING for details.

	For a total list of contributers see CREDITS.

	See http://www.clanlib.org
	------------------------------------------------------------------------
*/

//! clanDisplay="Sprites"
//! header=display.h

#ifndef header_sprite_packer
#define header_sprite_packer

#ifdef WIN32
#pragma warning( disable : 4786)
#endif

#include "surface.h"
#include "../Core/Math/size.h"
#include "../Core/Math/rect.h"

#include <vector>

class CL_SpriteDescription;
class CL_SpritePacker_Generic;

//: Packs sprite into one or more textures.
class CL_SpritePacker
{ 
//! Construction:
public:
	//: Constructs a CL_SpritePacker.
	CL_SpritePacker(const CL_SpriteDescription &description);

	~CL_SpritePacker();

//! Attributes:
public:
	//: Returns a list over all the textures needed for the packed-frames.
	//- <p> The get_frames() method returns a list consisting of many TexturePair, where each pair
	//- has an index into this list. </p>
	const std::vector<CL_Size> &get_texture_sizes() const;

	typedef std::pair<int, CL_Rect> TexturePair;	// int texture, CL_Rect frame_position
	//: Returns a list over all frames - which texture it is packed in and where within the
	//: texture it is located.
	//- <p> This list is arranged exactly the same order as the spritedescription frames. </p>
	const std::list<TexturePair> &get_frames() const;

//! Operations:
public:
	//: Packs all frames into one or more textures.
	//: Returns false if it was unable to pack all frames.
	bool pack(
		int max_width = 1024, int max_height = 1024,
		int min_width = 16, int min_height = 16,
		int max_textures = -1);

//! Implementation:
private:
	// Disallow copy construction.
	CL_SpritePacker(const CL_SpritePacker &copy);

	//: Disallow copy assignment.
	CL_SpritePacker &operator =(const CL_SpritePacker &copy);

	//: CL_SpritePacker implementation.
	CL_SpritePacker_Generic *impl;
};

#endif


