/*
	$Id: texture.h,v 1.14 2002/08/18 16:34:32 sphair Exp $

	------------------------------------------------------------------------
	ClanLib, the platform independent game SDK.

	This library is distributed under the GNU LIBRARY GENERAL PUBLIC LICENSE
	version 2. See COPYING for details.

	For a total list of contributers see CREDITS.

	See http://www.clanlib.org
	------------------------------------------------------------------------
*/

//! clanDisplay="Display 2D"
//! header=display.h

#ifndef header_texture
#define header_texture

#ifdef WIN32
#pragma warning( disable : 4786)
#endif

#include <string>
#include "../Core/Resources/resource.h"

class CL_PixelBuffer;
class CL_GraphicContext;
class CL_ResourceManager;
class CL_Texture_Generic;

//: Construct a texture.
class CL_Texture
{
//! Enums:
public:
	enum Hint
	{
		hint_opaque,   // surface only contain opaque data (no transparency)
		hint_colorkey, // surface only has colorkey alpha (transparency)
		hint_alpha     // surface with full alpha support (translucency)
	};

//! Construction:
public:
	// TODO: Add some hint to specify 16 or 32 bit surface.
	// TODO: Add some hint to specify mipmapping or not.

	//: Constructs a texture.
	//param provider: Image source for texture.
	//param delete_provider: If true, deletes provider after copying its image data.
	//param hint: Hints what sort of optimizations CL_Texture can perform to increase performance.
	//param resource_id: Resource name of a texture resource.
	//param manager: Resource manager used to load resource.
	//param filename: Image file used as image source for texture.
	CL_Texture();

	CL_Texture(
		CL_PixelBuffer *provider,
		bool delete_provider = false,
		Hint hint = hint_colorkey);

	CL_Texture(
		const std::string &resource_id,
		CL_ResourceManager *manager);

	CL_Texture(const std::string &filename, Hint hint = hint_colorkey);

	CL_Texture(const CL_Texture &copy);

	virtual ~CL_Texture();

//! Attributes:
public:
	//: Returns the width.
	int get_width() const;
	
	//: Returns the height.
	int get_height() const;
	
	//: Returns the width of the texture as stored in memory (as nearest 2^n of image size).
	int get_texture_width() const;
	
	//: Returns the height of the texture as stored in memory (as nearest 2^n of image size).
	int get_texture_height() const;

	//: Resource owning this texture, if any.
	CL_Resource resource;

//! Operations:
public:
	//: Copy assignment operator.
	CL_Texture &operator =(const CL_Texture &copy);

	//: Bind the texture.
	void bind(CL_GraphicContext *gc = 0);
	
//! Implementation:
private:
	CL_Texture_Generic *impl;
};

#endif
