/*
	$Id: opengl_window.h,v 1.9 2002/08/31 09:14:33 mbn Exp $

	------------------------------------------------------------------------
	ClanLib, the platform independent game SDK.

	This library is distributed under the GNU LIBRARY GENERAL PUBLIC LICENSE
	version 2. See COPYING for details.

	For a total list of contributers see CREDITS.

	See http://www.clanlib.org
	------------------------------------------------------------------------
*/

//! clanGL="Display 2D"
//! header=gl.h

#ifndef header_opengl_window
#define header_opengl_window

#include "../Display/display_window.h"

#ifdef WIN32
#include <wingdi.h>
#endif

//: OpenGL top level window.
class CL_OpenGLWindow : public CL_DisplayWindow
{
//! Construction:
public:
	//: Constructs an opengl window.
	//param title: Titlebar text.
	//param width, height: Size of window, in pixels.
	//param start_fullscreen: If true, window will go full screen.
	//param allow_resize: If true, window will have resize grabbers.
	//param flipping_buffer: Amount of buffers in flipping system.
	CL_OpenGLWindow();

	CL_OpenGLWindow(const CL_OpenGLWindow &copy);

	CL_OpenGLWindow(
		const std::string &title,
		int width,
		int height,
		bool start_fullscreen = false,
		bool allow_resize = false,
		int flipping_buffers = 2);

	~CL_OpenGLWindow();

//! Attributes:
public:
#ifdef WIN32
	//: Returns the Win32 OpenGL resource context.
	HGLRC get_context();

	//: Returns the Win32 device context handle.
	HDC get_dc();

	//: Returns the Win32 window handle.
	HWND get_wnd();
#endif

//! Operations:
public:
	//: Selects the opengl context for this window.
	void select_context();

//! Implementation:
private:
};

#endif
