/*
	$Id: menudata.h,v 1.23 2002/07/15 16:49:50 mbn Exp $

	------------------------------------------------------------------------
	ClanLib, the platform independent game SDK.

	This library is distributed under the GNU LIBRARY GENERAL PUBLIC LICENSE
	version 2. See COPYING for details.

	For a total list of contributers see CREDITS.

	See http://www.clanlib.org
	------------------------------------------------------------------------
*/

//! clanGUI="Controls"
//! header=gui.h

#ifndef header_menudata
#define header_menudata

class CL_Component;
class CL_PopupMenu;
class CL_MenuData_Generic;
class CL_MenuNode;

//: MenuData	
class CL_MenuData
{
//! Construction:
public:
	//: The menunode constructor.
	//- <p>Not to be constructed by user - use insert_item() instead, which
	//- creates a CL_MenuData.</p>
	CL_MenuData(CL_PopupMenu *popupmenu);
	
	virtual ~CL_MenuData();

//! Attributes:
public:
	//: Returns all components in this node.
	const std::list<CL_MenuNode *> &get_items() const;

//! Operations:
public:
	//: Inserts an item at index. 
	//- <p>If index is negative, text is inserted at the end of the list.
	//- Returns the node of the item.</p>
	CL_MenuNode *insert_item(const std::string &text, int index = -1);

	//: Inserts an item at index, with a submenu.
	//- <p>If index is negative, text is inserted at the end of the list.</p>
	//return: the node of the item.
	CL_MenuNode *insert_item(const std::string &text, CL_PopupMenu *submenu, int index = -1);

	//: Inserts an item (uses any type of component) at index. 
	//- <p>If index is negative, text is inserted at the end of the list.
	//- Set delete_component to true if you want the component to be deleted when
	//- this node gets deleted.</p>
	//return: the node of the item.
	CL_MenuNode *insert_item(CL_Component *component, bool delete_component = false, int index = -1);

	//: Inserts an item (uses any type of component) at index, with a submenu.
	//- <p>If index is negative, text is inserted at the end of the list.
	//- Set delete_component to true if you want the component to be deleted when
	//- this node gets deleted.</p>
	//return: the node of the item.
	CL_MenuNode *insert_item(CL_Component *component, CL_PopupMenu *submenu, bool delete_component = false, int index = -1);

	//: Deletes all items.
	void clear();

//! Implementation:
private:
	CL_MenuData(const CL_MenuData &copy) { return; } // disallow copy construction.
	CL_MenuData_Generic *impl;
};

#endif
