/*
	$Id: menunode.h,v 1.4 2002/07/15 16:49:50 mbn Exp $

	------------------------------------------------------------------------
	ClanLib, the platform independent game SDK.

	This library is distributed under the GNU LIBRARY GENERAL PUBLIC LICENSE
	version 2. See COPYING for details.

	For a total list of contributers see CREDITS.

	See http://www.clanlib.org
	------------------------------------------------------------------------
*/

//! clanGUI="Controls"
//! header=gui.h

#ifndef header_menunode
#define header_menunode

#include <string>

class CL_Point;
class CL_MenuNode_Generic;
class CL_Component;
class CL_PopupMenu;
class CL_Component;

//: MenuItem
class CL_MenuNode
{
//! Construction:
public:
	CL_MenuNode(CL_PopupMenu *submenu);
	
	virtual ~CL_MenuNode();

//! Attributes:
public:
	//: Returns true if node is selected
	bool is_selected() const;
	
	//: Return true if node has sub-items
	bool has_submenu() const;

	//: Returns the attaches userdata, if any.
	void *get_userdata() const;

	//: Returns the CL_Component this node uses.
	CL_Component *get_component() const;

//! Operations:
public:
	//: Sets/changes a new component for the node.
	//- <p>Mostly used when add(CL_Component *) is used with a NULL parameter.
	//- Set delete_component to true if you want the component to be deleted when
	//- this node gets deleted.</p>
	void set_component(CL_Component *component, bool delete_component = false);

	//: Select this node.
	void set_selected(bool select = true);

	//: Attaches userdata to node.
	void set_userdata(void *data);

//! Implementation:
private:
	CL_MenuNode(const CL_MenuNode &copy) { return; } // disallow copy construction.
	CL_MenuNode_Generic *impl;
};

#endif
