/*
	$Id: vorbis_soundprovider.h,v 1.14 2002/07/15 16:49:51 mbn Exp $

	------------------------------------------------------------------------
	ClanLib, the platform independent game SDK.

	This library is distributed under the GNU LIBRARY GENERAL PUBLIC LICENSE
	version 2. See COPYING for details.

	For a total list of contributers see CREDITS.

	See http://www.clanlib.org
	------------------------------------------------------------------------
*/

//! clanVorbis="Sound Providers"
//! header=vorbis.h

#ifndef header_vorbis_soundprovider
#define header_vorbis_soundprovider

#include "../core.h"
#include "../Sound/stream_soundprovider.h"
#include "../Sound/soundbuffer.h"

class CL_VorbisSoundProvider_Generic;

//: Vorbis Sound Provider Class
class CL_VorbisSoundProvider : public CL_StreamSoundProvider
{
public:
//! Construction:
	//: Vorbis Sound Provider Constructor
	//param name: The name of the file, either it's filename or descriptor from 'provider'
	//param provider: the InputsourceProvider to use
	//param delete_provider: If true, 'provider' will be delete when the destructor is called
	CL_VorbisSoundProvider(
		const std::string &name,
		CL_InputSourceProvider *provider = NULL,
		bool delete_provider = false);

	//: Vorbis Sound Provider Constructor
	//param name: The name of the vorbis file in 'resources'
	//param	resources: The ResourceManager to use to access the resource identified by 'name'
	CL_VorbisSoundProvider(
		const std::string &name,
		CL_ResourceManager *resources);

	//: Vorbis Sound Provider Destructor
	virtual ~CL_VorbisSoundProvider();

//! Operations:
	//: Begin Session
	//return: A CL_StreamSoundProvider_Session object for the resource named in the constructor
	virtual CL_StreamSoundProvider_Session *begin_session();

	//: End Session
	//- <p>Deletes the object 'session'</p>
	//param session: The CL_StreamSoundProvider_Session to be deleted
	virtual void end_session(CL_StreamSoundProvider_Session *session);

//! Implementation:
private:
	CL_VorbisSoundProvider(const CL_VorbisSoundProvider &copy) { return; } // disallow copy construction.
	CL_VorbisSoundProvider_Generic *impl;
};

#endif
